@@ -7,7 +7,7 @@ from gridsource.validation import ValidatorMixin
 
 __author__ = """Nicolas Cordier"""
 __email__ = "nicolas.cordier@numeric-gmbh.ch"
-__version__ = "1.2.0"
+__version__ = "1.3.0"
 
 
 class _Base:
@@ -18,12 +18,16 @@ class _Base:
             if hasattr(self, f):
                 getattr(self, f)()
 
-    def get(self, tabname=None, attr="_data"):
+    def get(self, tabname=None, attr="_data", remove_hidden_cols=True):
         if not attr.startswith("_"):
             attr = "_" + attr
         if not tabname:
             raise AttributeError(f"`tabname` should be one of {set(self._data.keys())}")
-        return getattr(self, attr)[tabname]
+        data = getattr(self, attr)[tabname]
+        if attr == "_data" and remove_hidden_cols:
+            # early remove __<col>
+            data = data.loc[:, ~data.columns.str.startswith("__")]
+        return data
 
     def tabs(self, ordered=False):
         """return contained tabs"""
