@@ -624,9 +624,9 @@ class ValidatorMixin:
             return units[key]
         return units
 
-    def getrow(self, tabname, key, search_by=None):
+    def getrow(self, tabname, key, search_by=None, remove_hidden_cols=True):
         """retrieve a row from any tabname, eventually sorting by `search_by`"""
-        df = self.get(tabname).copy()
+        df = self.get(tabname, remove_hidden_cols=remove_hidden_cols).copy()
         if search_by:
             df.set_index(search_by, inplace=True)
         return df.loc[key]
