@@ -659,7 +659,7 @@ def test_IVData_06_units(datadir):
     with pytest.raises(KeyError):
         data_imp.getunits("length", key="id")
     # getvalue
-    l9 = data_SI.getrow("length", key=9, search_by="id")
+    l9 = data_SI.getrow("length", key=9, search_by="id", remove_hidden_cols=False)
     l9_expected = pd.Series(
         {
             "test_dist_m": 2000,
@@ -729,7 +729,7 @@ def test_IVData_07_failing_units(datadir):
                 "'a' is not of type 'number'",
                 "'a' is not of type 'null'",
             ],
-            ("test_mass_lb", "?"): "cannot convert some values to numeric",
+            ("test_mass_lb", "?"): ["cannot convert some values to numeric"],
         }
     }
 
